<?php
date_default_timezone_set("PRC"); // 统一时区设置

require_once 'RSAUtil.php';
require_once 'HttpUtil.php';

class GepUtil
{
    private const AGENT_NO = "5182210819000222768";
    private const CERTIFICATE_ID = "2211211448000022579";
    private const PFX_NAME = "privatekey.pfx";
    private const CER_NAME = "publickey.cer";
    private const PFX_PASS = "5181221121000514358_416342";
    
    private const MAIN_URL = "https://member-test-api.gepholding.com";
    private const VERSION = "1.0.0";
    private const DATA_TYPE = "JSON";
    private const LOG_DIR = __DIR__ . '/../log/';
    
    
    public static function log(string $message): void
    {
        $logPath = self::LOG_DIR;
        if (!is_dir($logPath)) {
            mkdir($logPath, 0777, true);
        }
        $filePath = $logPath . 'log' . date('Ymd') . '.txt';
        $logTime = date('Y-m-d H:i:s');
        file_put_contents($filePath, "[$logTime]:$message\r\n", FILE_APPEND);
    }

    public static function echoFormat(string $message): void
    {
        $logTime = date('Y-m-d H:i:s');
        echo "$logTime	: $message<br>";
    }

    public static function generateRandomString(): string
    {
        return date('YmdHis') . uniqid();
    }
    
    /**
     * 发送请求
     * 
     * @param string $url 请求的URL
     * @param array $params 请求的参数
     * @param array|null $fileParams 上传的文件
     * @param bool $hasDecryptResult 是否解密响应结果
     * @return string 响应内容
     */
    public static function sendRequest($url, $params, $fileParams = null, $hasDecryptResult = true)
    {
        try {
            // 验证输入
            if (!is_array($params)) {
                throw new InvalidArgumentException("Params must be an array");
            }
            
            // 组装请求数据
            $dataContentJson = json_encode($params);
            self::echoFormat("dataContent组装明文:" . $dataContentJson);

            // 加密请求数据
            $ServicesPath = dirname(dirname(__FILE__));
            $privateKeyPath = $ServicesPath . "/file/" . self::PFX_NAME;
            $encryptedDataContent = RSAUtil::encryptByPrivateKeyFile($dataContentJson, $privateKeyPath, self::PFX_PASS);
            self::echoFormat("dataContent密文:" . $encryptedDataContent);
            
            // 准备POST字段
            $postFields = [
                'version' => self::VERSION,
                'certificateId' => self::CERTIFICATE_ID,
                'agentNo' => self::AGENT_NO,
                'dataType' => self::DATA_TYPE,
                'dataContent' => $encryptedDataContent,
                'apiType' => '1',
                'userNo' => $params["userNo"],
            ];
            self::echoFormat("请求地址:" . self::MAIN_URL . $url);

            // 发送HTTP请求
            $additionalHeaders = [];
            // 英文code
            // $additionalHeaders[] = "Accept-Language:en-US";
            $response = HttpUtil::post(self::MAIN_URL . $url, $postFields, $fileParams, $additionalHeaders);
            self::echoFormat("响应报文:" . $response);
            
            // 处理响应
            if (!$hasDecryptResult) {
                return $response;
            }
            self::decryptDataContent($response);

        } catch (Exception $e) {
            self::log("Error: " . $e->getMessage());
            echo "Error: " . $e->getMessage();
        }
    }

    public static function decryptDataContent($response)
    {
        $resJson = json_decode($response, true);
        $ServicesPath = dirname(dirname(__FILE__));
        if (is_array($resJson) && $resJson["success"]) {
            $result = $resJson["result"];
            $publicKeyPath = $ServicesPath . "/file/" . self::CER_NAME;
            $result = RSAUtil::decryptByPublicKeyFile($result, $publicKeyPath);
            self::echoFormat("result解密明文:" . $result);
        } else {
            self::echoFormat("错误描述errorMsg:" . $resJson["errorMsg"]);
        }
    }

}